/* Stereograph
 * Header file;
 * Copyright (c) 2000 by Fabian Januszewski <fabian.linux@januszewski.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


/* gfx io functions */
int Read_Gfx_File (char *file_name, struct GFX_DATA *gfx);
int Write_Gfx_File (char *file_name, struct GFX_DATA *gfx);


/* gfxio internals */
int Read_TARGA (FILE *ifile, struct GFX_DATA *gfx);
int Read_TARGA_RGB(FILE *ifile, int bits, int *palette, int *c);

int Write_PIPE (FILE *pp, struct GFX_DATA *gfx);
int Write_TARGA (FILE *ofile, struct GFX_DATA *gfx);
